import os, sys
from AccessGrid.Venue import VenueIW
from AccessGrid.ClientProfile import ClientProfile
from AccessGrid.SharedAppClient import SharedAppClient
from AccessGrid.Platform.Config import UserConfig
from AccessGrid import Toolkit

#
# A simple example showing how to join a shared application.
#

# You should first initialize the toolkit for Access Grid
#   Shared Applications.  It's not required for everything, but
#   it allows you to use various things such as certificates,
#    logging, and your Access Grid configuration and information.

print "- Initializing AG Toolkit."
app = Toolkit.CmdlineApplication.instance()
app.Initialize("BasicApp")


def SetupTest(venueUrl):
    # The url of the venue we're working in:
    venueProxy = VenueIW(venueUrl)

    # --- Create a new shared application in the venue for testing.
    appDescription = venueProxy.CreateApplication(
            "test app name",
            "test app description",
            "test app mimeType" )
    appUrl = str(appDescription.uri)
    # --- 
    return venueProxy, appUrl, appDescription

def GetClientProfile():
    clientProfileFile = os.path.join(UserConfig.instance().GetConfigDir(),
                                     "profile")
    clientProfile = ClientProfile(clientProfileFile)
    return clientProfile

# Read a venueUrl from the cmd-line if necessary.
if len(sys.argv) > 1:
    venueUrl = sys.argv[1]
    print "- Testing in venue from cmd-line:", venueUrl
else:
    venueUrl = "https://localhost:8000/Venues/default"
    print "- Testing in default local venue.  Pass a venueUrl on the cmd-line to specify a different venue."

print "- Creating a test shared application in a venue."
venueProxy, appUrl, appDescription = SetupTest(venueUrl)

sharedAppClient = SharedAppClient("BasicApp")
sharedAppClient.InitLogging()

print "- Joining the Shared Application."
sharedAppClient.Join(appUrl, GetClientProfile() )
print "- Finished Joining"

print "- Shutting down."
# Disconnect and shutdown before we exit (not required, but helpful).
sharedAppClient.Shutdown()

print "- Removing test shared application from the venue."
venueProxy.DestroyApplication(appDescription.id)

print "- Finished."
