import os, sys
from AccessGrid.Venue import VenueIW
from AccessGrid.ClientProfile import ClientProfile
from AccessGrid.SharedAppClient import SharedAppClient
from AccessGrid.Platform.Config import UserConfig
from AccessGrid import Toolkit

#
# Get Basic Information about a shared application.
#

print "- Initializing AG Toolkit."
app = Toolkit.CmdlineApplication.instance()
app.Initialize("GetSharedAppState")

def SetupTest(venueUrl):
    venueProxy = VenueIW(venueUrl)

    # --- Create a new shared application in the venue for testing.
    appDescription = venueProxy.CreateApplication(
            "test app name",
            "test app description",
            "test app mimeType" )
    appUrl = str(appDescription.uri)
    # --- 
    return venueProxy, appUrl, appDescription

def GetClientProfile():
    clientProfileFile = os.path.join(UserConfig.instance().GetConfigDir(),
                                     "profile")
    clientProfile = ClientProfile(clientProfileFile)
    return clientProfile

# --- 
# Read a venueUrl from the cmd-line if necessary.
if len(sys.argv) > 1:
    venueUrl = sys.argv[1]
    print "- Testing in venue from cmd-line:", venueUrl
else:
    venueUrl = "https://localhost:8000/Venues/default"
    print "- Testing in default local venue.  Pass a venueUrl on the cmd-line to specify a different venue."

print "- Creating a test shared application in a venue."
venueProxy, appUrl, appDescription = SetupTest(venueUrl)

sharedAppClient = SharedAppClient("GetSharedAppState")
sharedAppClient.InitLogging()

print "- Joining the Shared Application."
sharedAppClient.Join(appUrl, GetClientProfile() )
print "- Finished Joining"

print "- Getting Application State:"
state = sharedAppClient.GetApplicationState()
print "  Application State:"
print '    name:', state.name
print '    desc:', state.description
print '    id:', state.id
print '    mimeType:', state.mimeType
print '    uri:', state.uri
print '    data:', state.data

print "- Shutting down."
# Disconnect and shutdown before we exit (not required, but helpful).
sharedAppClient.Shutdown()

print "- Removing test shared application from the venue."
venueProxy.DestroyApplication(appDescription.id)

print "- Finished."
