import os, sys
from AccessGrid.Venue import VenueIW
from AccessGrid.ClientProfile import ClientProfile
from AccessGrid.SharedAppClient import SharedAppClient
from AccessGrid.Platform.Config import UserConfig
from AccessGrid import Toolkit

#
# Setting and Getting Shared App Data
#

print "- Initializing AG Toolkit."
app = Toolkit.CmdlineApplication.instance()
app.Initialize("SharedAppVenueDataExample")

# Read a venueUrl from the cmd-line if necessary.
if len(sys.argv) > 1:
    venueUrl = sys.argv[1]
    print "- Testing in venue from cmd-line:", venueUrl
else:
    venueUrl = "https://localhost:8000/Venues/default"
    print "- Testing in default local venue.  Pass a venueUrl on the cmd-line to specify a different venue."
venueProxy = VenueIW(venueUrl)

print "- Creating a test shared application in a venue."
appDescription = venueProxy.CreateApplication(
            "test app name",
            "test app description",
            "test app mimeType" )
appUrl = appDescription.uri

print "- Joining the Shared Application."
sharedAppClient = SharedAppClient("testApp")
sharedAppClient.InitLogging()

# Get client profile
clientProfileFile = os.path.join(UserConfig.instance().GetConfigDir(),
                                     "profile")
clientProfile = ClientProfile(clientProfileFile)
sharedAppClient.Join(appUrl, clientProfile)

print "-- Set app data"
testKey = "test key"
testValue = "test value"
print "   ", testKey, ":", testValue
sharedAppClient.SetData( testKey, testValue )

print "-- Get app data keys"
keys = sharedAppClient.GetDataKeys()
for k in keys:
    print "   ", k

print "-- Get app data"
retVal = sharedAppClient.GetData( keys[0] )
print "   ", keys[0], ":", retVal
if not retVal == testValue:
    print "FAILURE: Get data returned different value than was set"

print "- Shutting down."
# Disconnect and shutdown before we exit (not required, but helpful).
sharedAppClient.Shutdown()

print "- Removing test shared application from the venue."
venueProxy.DestroyApplication(appDescription.id)

print "- Finished."
