import os, traceback, sys
from AccessGrid.Venue import VenueIW
from AccessGrid.ClientProfile import ClientProfile
from AccessGrid.SharedAppClient import SharedAppClient
from AccessGrid.Platform.Config import UserConfig
from AccessGrid import Toolkit

try:
    from twisted.internet import _threadedselect as threadedselectreactor
except:
    from twisted.internet import threadedselectreactor
try:
    threadedselectreactor.install()
except:
    pass

#
# Sending and Receiving Shared Application Events.
#

print "- Initializing AG Toolkit."
app = Toolkit.CmdlineApplication.instance()
app.Initialize("AppEvents")

def SetupTest(venueUrl):
    venueProxy = VenueIW(venueUrl)

    # --- Create a new shared application in the venue for testing.
    appDescription = venueProxy.CreateApplication(
            "test app name",
            "test app description",
            "test app mimeType" )
    appUrl = str(appDescription.uri)
    # --- 
    return venueProxy, appUrl, appDescription

def GetClientProfile():
    clientProfileFile = os.path.join(UserConfig.instance().GetConfigDir(),
                                     "profile")
    clientProfile = ClientProfile(clientProfileFile)
    return clientProfile


# Read a venueUrl from the cmd-line if necessary.
if len(sys.argv) > 1:
    venueUrl = sys.argv[1]
    print "- Testing in venue from cmd-line:", venueUrl
else:
    venueUrl = "https://localhost:8000/Venues/default"
    print "- Testing in default local venue.  Pass a venueUrl on the cmd-line to specify a different venue."

print "- Creating a test shared application in a venue."
venueProxy, appUrl, appDescription = SetupTest(venueUrl)

sharedAppClient = SharedAppClient("AppEvents")
sharedAppClient.InitLogging()

print "- Joining the Shared Application."
sharedAppClient.Join(appUrl, GetClientProfile() )
print "- Finished Joining"

def shutdown():
    print "- Shutting down."
    reactor.stop()

    # Disconnect and shutdown before we exit (not required, but helpful).
    sharedAppClient.Shutdown()

    print "- Removing test shared application from the venue."
    venueProxy.DestroyApplication(appDescription.id)

    print "- Finished."

def event1Callback(eventDesc):
    try:
        print "- Received event."
        print "    Type: %s," % eventDesc.GetEventType(), "Data:", eventDesc.GetData()
        shutdown()
    except:
        traceback.print_exc()

sharedAppClient.RegisterEventCallback("event1", event1Callback )

def sendEvent():
    print "- Sending event."
    print "    Type: event1, Data: somedata"
    sharedAppClient.SendEvent("event1", "somedata")

# Call a function once the event client has been connected.
sharedAppClient.eventClient.RegisterMadeConnectionCallback(sendEvent)

from twisted.internet import reactor
reactor.run()

