import os, sys
from AccessGrid.Venue import VenueIW
from AccessGrid.ClientProfile import ClientProfile
from AccessGrid.SharedAppClient import SharedAppClient
from AccessGrid.Platform.Config import Config, UserConfig
from AccessGrid.DataStoreClient import GetVenueDataStore
from AccessGrid.Platform.Config import SystemConfig
from AccessGrid.interfaces.VenueClient_client import VenueClientIW
from AccessGrid.GUID import GUID
from AccessGrid import Toolkit

from AccessGrid.Toolkit import CmdlineApplication

print "- Initializing AG Toolkit."
Toolkit.CmdlineApplication()
app = Toolkit.CmdlineApplication.instance()
app.Initialize("SharedAppVenueDataExample")

#
# Access the Venue datastore and upload or download data.
#

if len(sys.argv) < 3:
    print "  <venueUrl> <connectionID> not specified on the cmd-line."
    from AccessGrid.VenueClient import GetVenueClientUrls
    venueClientUrls = GetVenueClientUrls()
    print "  Will attempt to request a connectionId (and venueURL) from a local VenueClient"
    if len(venueClientUrls) > 0:
        venueClient = VenueClientIW(venueClientUrls[0])
        connectionId = venueClient.GetClientProfile().connectionId
        print "  VenueClient's ConnectionId: ", connectionId
        venueURL = str(venueClient.GetVenueURL())
        print "  VenueClient's venueURL: ", venueURL
    else:
        print "Specify a connectionID on the command-line or connect a VenueClient to venue."
        sys.exit()
else:
    connectionId = sys.argv[1] 


def GetClientProfile():
    clientProfileFile = os.path.join(UserConfig.instance().GetConfigDir(),
                                     "profile")
    clientProfile = ClientProfile(clientProfileFile)
    return clientProfile


# The url of the venue we're working in:
venueUrl = "https://localhost:8000/Venues/default"
venueProxy = VenueIW(venueUrl)

print "- Creating a test shared application in a venue."
appDescription = venueProxy.CreateApplication(
            "test app name",
            "test app description",
            "test app mimeType" )
appUrl = str(appDescription.uri)

sharedAppClient = SharedAppClient("SharedAppVenueData")
sharedAppClient.InitLogging()

print "- Joining the Shared Application."
sharedAppClient.Join(appUrl, GetClientProfile() )
print "- Finished Joining"

dataStoreClient = GetVenueDataStore(venueUrl, connectionId)

print "- Querying files in dataStore: "
filenames = dataStoreClient.QueryMatchingFiles("*")
print "    Venue files:", filenames

# create a file to upload
hostname = SystemConfig.instance().GetHostname()
filename = "tmp_%s.txt" % hostname
f = open(filename, "w").write("This is a test file.\n")
print "- Uploading: ", filename
dataStoreClient.Upload(filename)

print "- Refreshing local list of data files."
dataStoreClient.LoadData()

print "- Requerying files in dataStore (."
filenames = dataStoreClient.QueryMatchingFiles("*")
print "    Venue files:", filenames

print "- File data:\n    ", dataStoreClient.GetFileData(filename)

print "- Downloading: ", filename
downloadFilename = "downloaded_" + filename
dataStoreClient.Download(filename, downloadFilename)

print "- Removing file from venue"
dataStoreClient.RemoveFile(filename)

print "- Removing test shared application from the venue."
venueProxy.DestroyApplication(appDescription.id)

print "- Finished."
