import os, sys, traceback
from AccessGrid.Venue import VenueIW
from AccessGrid.ClientProfile import ClientProfile
from AccessGrid.SharedAppClient import SharedAppClient
from AccessGrid.Platform.Config import Config, UserConfig
from AccessGrid.DataStoreClient import GetVenueDataStore
from AccessGrid.Platform.Config import SystemConfig
from AccessGrid.interfaces.VenueClient_client import VenueClientIW
from AccessGrid.GUID import GUID
from AccessGrid import Toolkit
from AccessGrid import icons
from wxPython.wx import *

from AccessGrid.Toolkit import WXGUIApplication
try:
    from twisted.internet import _threadedselect as threadedselectreactor
except:
    from twisted.internet import threadedselectreactor
try:
    threadedselectreactor.install()
except:
    pass
from twisted.internet import reactor

class SharedAppExample(wxApp):
    def __init__( self, appUrl):
        wxApp.__init__(self, False)
        self.reactorFinished = []

        reactor.interleave(wxCallAfter)

        name = sys.argv[0]
        self.sharedAppClient = SharedAppClient(name)
        self.log = self.sharedAppClient.InitLogging()

        # Get client profile
        try:
            clientProfileFile = os.path.join(UserConfig.instance().GetConfigDir(), "profile")
            clientProfile = ClientProfile(clientProfileFile)
        except:
            self.log.info("SharedAppClient.Connect: Could not load client profile, set clientProfile = None")
            clientProfile = None

        print "- Joining the Shared Application."
        self.sharedAppClient.Join(appUrl, clientProfile)
        print "- Join finished."

        # Call a function once the event client has been connected.
        self.sharedAppClient.eventClient.RegisterMadeConnectionCallback(self.madeConnectionCallback)

        self.frame = wxFrame(None, -1, "Shared App Example")

        self.hsizer = wxStaticBoxSizer(wxStaticBox(self.frame, -1, "My Buttons"), wxHORIZONTAL)
        self.button1Id = wxNewId()
        self.button1 = wxButton(self.frame, self.button1Id,
                        "Button 1", wxDefaultPosition, wxDefaultSize)
        self.quitButtonId = wxNewId()
        self.quitButton = wxButton(self.frame, self.quitButtonId,
                        "Quit", wxDefaultPosition, wxDefaultSize)

        self.mainSizer=wxBoxSizer(wxVERTICAL);
        self.mainSizer.Add(self.hsizer, 0, wxALIGN_CENTER | wxGROW | wxALL, 5)
        self.hsizer.Add(self.button1, 0, wxALIGN_CENTER | wxGROW | wxALL, 5)
        self.hsizer.Add(self.quitButton, 0, wxALIGN_CENTER | wxGROW | wxALL, 5)

        EVT_BUTTON(self.frame, -1, self.OnButton)
        EVT_BUTTON(self.frame, self.quitButtonId, self.Quit)
        self.frame.SetSizer(self.mainSizer);
        self.frame.SetAutoLayout(true);

        self.frame.SetIcon(icons.getAGIconIcon())
        self.frame.Show(1)
        self.SetTopWindow(self.frame)

    def OnButton(self, event):
        if event.GetId() == self.button1Id:
            print "  Button 1 pressed"
        else:
            print "  Unhandled button with id:", event.GetId()

    def madeConnectionCallback(self):
        try:
            self.log.debug("MadeConnection")
            print "  Event client connection made. (Quit in gui to continue)"
        except:
            traceback.print_exc()
            self.log.exception()

    def Quit(self, event=None):
        print "  Quit button pressed."
        self.frame.Close()

    def ReactorFinished(self):
        self.reactorFinished.append(True)

    def OnExit(self):
        print "- Shutting down."
        reactor.stop()

        try:
            # print "Shutting down shared app client"
            self.sharedAppClient.Shutdown()
        except:
            traceback.print_exc()

        # Allow twisted reactor to finish.
        while len(self.reactorFinished) == 0:
            reactor.iterate()

if __name__ == "__main__":

    print "- Initializing AG Toolkit."
    app = Toolkit.WXGUIApplication.instance()
    app.Initialize(sys.argv[0])

    # Read a venueUrl from the cmd-line if necessary.
    if len(sys.argv) > 1:
        venueUrl = sys.argv[1]
        print "- Testing in venue from cmd-line:", venueUrl
    else:
        venueUrl = "https://localhost:8000/Venues/default"
        print "- Testing in default local venue.  Pass a venueUrl on the cmd-line to specify a different venue."

    venue = VenueIW(venueUrl)

    print "- Creating a test shared application in a venue."
    appDescription = venue.CreateApplication(
            "test app name",
            "test app description",
            "test app mimeType" )
    appUrl = str(appDescription.uri)


    wxInitAllImageHandlers()
    app = SharedAppExample(appUrl)
    reactor.addSystemEventTrigger('after', 'shutdown', app.ReactorFinished)
    app.MainLoop()

    print "- Removing test App from Venue."
    # Remove the test shared app from the venue.
    try:
        venue.DestroyApplication(appDescription.id)
        print "- Test app removed from Venue."
    except:
        traceback.print_exc()

    #import threading
    #for thrd in threading.enumerate():
    #    print "Thread %s" % thrd

    print "- Finished."

    # Use this until we have clean shutdowns by using twisted 2.5's wxReactor.
    os._exit(0)


